/**
 * Copyright ou © ou Copr. Ministère de l'Europe et des Affaires étrangères (2017)
 * <p/>
 * pole-architecture.dga-dsi-psi@diplomatie.gouv.fr
 * <p/>
 * Ce logiciel est un programme informatique servant à faciliter la création
 * d'applications Web conformément aux référentiels généraux français : RGI, RGS et RGAA
 * <p/>
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 * <p/>
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * <p/>
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 * <p/>
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 * <p/>
 * <p/>
 * Copyright or © or Copr. Ministry for Europe and Foreign Affairs (2017)
 * <p/>
 * pole-architecture.dga-dsi-psi@diplomatie.gouv.fr
 * <p/>
 * This software is a computer program whose purpose is to facilitate creation of
 * web application in accordance with french general repositories : RGI, RGS and RGAA.
 * <p/>
 * This software is governed by the CeCILL license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 * <p/>
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited
 * liability.
 * <p/>
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 * <p/>
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 *
 */

/**
 * hornet-js-react-components - Ensemble des composants web React de base de hornet-js
 *
 * @author MEAE - Ministère de l'Europe et des Affaires étrangères
 * @version v5.2.0
 * @link git+https://github.com/diplomatiegouvfr/hornet-js.git
 * @license CECILL-2.1
 */

import { Utils } from "hornet-js-utils";
import { Logger } from "hornet-js-utils/src/logger";

import * as React from "react";


import { AbstractField, AbstractFieldProps }  from "hornet-js-react-components/src/widget/form/abstract-field";
import {
    IHornetComponentDatasource,
    IHornetComponentAsync,
} from "hornet-js-components/src/component/ihornet-component";
import { HornetComponent, HornetComponentDatasourceProps }  from "hornet-js-react-components/src/widget/component/hornet-component";
import { DataSource } from "hornet-js-core/src/component/datasource/datasource";
import { SpinnerComponentInput }  from "hornet-js-react-components/src/widget/spinner/spinner-component-input";
import { SpinnerProps }  from "hornet-js-react-components/src/widget/spinner/spinner-component";

const logger: Logger = Utils.getLogger("hornet-js-react-components.widget.form.abstract-field-datasource");

/**
 * Représente un champ de formulaire qui possède un datasource
 */
export abstract class AbstractFieldDatasource<P extends HornetComponentDatasourceProps & AbstractFieldProps, S> extends AbstractField<HornetComponentDatasourceProps & AbstractFieldProps, S> implements IHornetComponentDatasource, IHornetComponentAsync {

    readonly props: Readonly<HornetComponentDatasourceProps & AbstractFieldProps>;

    constructor(props?: HornetComponentDatasourceProps & AbstractFieldProps, context?: any) {
        super(props, context);
    }

    /**
     * Méthode qui controle l'affichage et la suppression du spinner
     * @param flag booléen true pour l'afficher false sinon
     */
    displaySpinner(flag: boolean) {
        (this.state as any).inProgress = flag;
        if (!this.props.hideSpinner) {
            this.refs.spinnerLoader && (this.refs.spinnerLoader as SpinnerComponentInput<SpinnerProps, SpinnerProps>).progress(flag);
            flag ? this.showSpinnerComponent() : this.hideSpinnerComponent();
        }
    }


    /**
     * @inheritDoc
     */
    componentWillMount() {
        super.componentWillMount();
        if (this.props.dataSource) {
            this.setItem();
        }
    }

    /**
     * @inheritDoc
     */
    componentDidMount() {
        super.componentDidMount();
        if (this.props.dataSource) {
            this.props.dataSource.on("fetch", this.setItem);
            this.props.dataSource.on("init", this.setItem);
            this.props.dataSource.on("add", this.setItem);
            this.props.dataSource.on("delete", this.setItem);
            this.props.dataSource.on("sort", this.setItem);
            this.props.dataSource.on("filter", this.setItem);
            this.props.dataSource.on("loadingData", this.displaySpinner);
        }
    }

    /**
     * @inheritDoc
     */
    componentWillUnmount() {
        super.componentWillUnmount();
        if (this.props.dataSource) {
            this.props.dataSource.removeListener("fetch", this.setItem);
            this.props.dataSource.removeListener("init", this.setItem);
            this.props.dataSource.removeListener("add", this.setItem);
            this.props.dataSource.removeListener("delete", this.setItem);
            this.props.dataSource.removeListener("sort", this.setItem);
            this.props.dataSource.removeListener("filter", this.setItem);
            this.props.dataSource.removeListener("loadingData", this.displaySpinner);
        }
    }

    /**
     * enregistre la liste des choix possibles
     */
    protected setItem() {
        this.setState({ items: this.props.dataSource.results });
        /* permet de faire appel a la méthode setCurrentValue de dom-adapter pour cocher les valeurs*/
        this.setCurrentValue(this.state.currentValue);
    }

    /**
     * Méthode premettant d'afficher le spinner
     * @returns {Table}
     */
    showSpinnerComponent(): this {
        this.setState({ spinner: true });
        return this;
    }

    /**
     * Méthode premettant de masquer le spinner
     * @returns {Table}
     */
    hideSpinnerComponent(): this {
        this.setState({ spinner: false });
        return this;
    }

    public setDataSource(value: DataSource<any>, callback?: () => any) {
        /** liste des choix disponibles */
        this.setState({ dataSource: value }, callback);
        return this;
    }


    public updateDataSource(value: any) {
        this.setDataSource(value);
    }

    /**
     * Génère le rendu des élements assurant la saisie des valeurs
     * @returns {any}
     */
    renderField(): JSX.Element {
        return (
            <div className={this.state.fieldClass + " abstractfield-field-content"}>
                {<SpinnerComponentInput ref="spinnerLoader" isVisible={this.state.spinner} />}
                {this.state.prefix ? <span className="abstractfield-field-prefix">{this.state.prefix}</span> : null}
                {this.renderWidget()}
                {this.state.suffix ? <span className="abstractfield-field-suffix">{this.state.suffix}</span> : null}
                {this.renderErrors()}
            </div>
        );
    }
}
